"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runDepsStatusCheck = runDepsStatusCheck;
const path_1 = __importDefault(require("path"));
const execa_1 = require("execa");
const error_1 = require("@pnpm/error");
const logger_1 = require("@pnpm/logger");
const deps_status_1 = require("@pnpm/deps.status");
const enquirer_1 = require("enquirer");
async function runDepsStatusCheck(opts) {
    const { upToDate, issue } = await (0, deps_status_1.checkDepsStatus)(opts);
    if (upToDate)
        return;
    switch (opts.verifyDepsBeforeRun) {
        case 'install':
            install();
            break;
        case 'prompt': {
            const confirmed = await (0, enquirer_1.prompt)({
                type: 'confirm',
                name: 'runInstall',
                message: `Your "node_modules" directory is out of sync with the "pnpm-lock.yaml" file. This can lead to issues during scripts execution.

Would you like to run "pnpm install" to update your "node_modules"?`,
                initial: true,
            });
            if (confirmed.runInstall) {
                install();
            }
            break;
        }
        case 'error':
            throw new error_1.PnpmError('VERIFY_DEPS_BEFORE_RUN', issue ?? 'Your node_modules are out of sync with your lockfile', {
                hint: 'Run "pnpm install"',
            });
        case 'warn':
            (0, logger_1.globalWarn)(`Your node_modules are out of sync with your lockfile. ${issue}`);
            break;
    }
    function install() {
        const execOpts = {
            cwd: opts.dir,
            stdio: 'inherit',
        };
        if (path_1.default.basename(process.execPath) === 'pnpm') {
            (0, execa_1.sync)(process.execPath, ['install'], execOpts);
        }
        else if (path_1.default.basename(process.argv[1]) === 'pnpm.cjs') {
            (0, execa_1.sync)(process.execPath, [process.argv[1], 'install'], execOpts);
        }
        else {
            (0, execa_1.sync)('pnpm', ['install'], execOpts);
        }
    }
}
//# sourceMappingURL=runDepsStatusCheck.js.map